@@ -203,11 +203,14 @@ def slice(footage_play_dir, full_footage_file, gobj, coach=True,
 
     unsliced = unsliced_plays(footage_play_dir, gobj, coach, dry_run)
     if unsliced is None or len(unsliced) == 0:
-        _eprint(
-            'There are no unsliced plays remaining for game %s %s.\n'
-            'If they have not been sliced yet, then the XML play-by-play '
-            'meta data may not be available or is corrupt.'
-            % (gobj, _nice_game(gobj)))
+        # Only show an annoying error message if there are no sliced
+        # plays on disk.
+        if not footage_plays(footage_play_dir, gobj):
+            _eprint(
+                'There are no unsliced plays remaining for game %s %s.\n'
+                'If they have not been sliced yet, then the XML play-by-play '
+                'meta data may not be available or is corrupt.'
+                % (gobj, _nice_game(gobj)))
         return
 
     pool = eventlet.greenpool.GreenPool(threads)
@@ -216,7 +219,7 @@ def slice(footage_play_dir, full_footage_file, gobj, coach=True,
                      0, True)
     pool.waitall()
 
-    _eprint('DONE slicing game %s' % _nice_game(gobj))
+    _eprint('DONE slicing game %s %s' % (gobj.eid, _nice_game(gobj)))
 
 
 def artificial_slice(footage_play_dir, gobj, gobj_play):
@@ -353,7 +356,7 @@ def download_broadcast(footage_dir, gobj, quality='1600', dry_run=False):
     if not _run_command(cmd):
         _eprint('FAILED to download game %s' % _nice_game(gobj))
     else:
-        _eprint('DONE with game %s' % _nice_game(gobj))
+        _eprint('DONE with game %s %s' % (gobj.eid, _nice_game(gobj)))
 
 
 def download_coach(footage_dir, gobj, dry_run=False):
@@ -388,11 +391,12 @@ def download_coach(footage_dir, gobj, dry_run=False):
     _eprint('Downloading game %s %s' % (gobj.eid, _nice_game(gobj)))
     status = _run_command(cmd)
     if status is None:
-        _eprint('DONE (incomplete) with game %s' % _nice_game(gobj))
+        _eprint('DONE (incomplete) with game %s %s'
+                % (gobj.eid, _nice_game(gobj)))
     elif not status:
         _eprint('FAILED to download game %s' % _nice_game(gobj))
     else:
-        _eprint('DONE with game %s' % _nice_game(gobj))
+        _eprint('DONE with game %s %s' % (gobj.eid, _nice_game(gobj)))
 
 
 def _run_command(cmd):
